part of init;

final _analysisOptionsTemp = '''
include: package:flutter_lints/flutter.yaml

linter:
  rules:
    avoid_setters_without_getters: false
    avoid_positional_boolean_parameters: false
    sort_pub_dependencies: false
    directives_ordering: false

analyzer:
  errors:
    unused_import: warning

  strong-mode:
    implicit-casts: true
'''
        .trim() +
    '\n';

final _packagesTemp = [
  Packages.bot_toast,
  Packages.provider,
  Packages.easy_localization,
  Packages.chaotic,
];

const _assetsTemp = '''
  
  assets:
    - assets/lang/
''';

final _mainTemp = '''
import 'package:bot_toast/bot_toast.dart';
import 'package:easy_localization/easy_localization.dart';
${Chaotic._applicationFile ?? '''
import 'package:provider/provider.dart';
import 'src/screen/screens.dart';
import 'package:chaotic/commons.dart';
import 'package:flutter/material.dart';
'''}


Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();

  Provider.debugCheckInvalidValueType = null;
  
  runApp(
    EasyLocalization(
      supportedLocales: const [
        Locale('en'),
        Locale('ar'),
      ],
      path: 'assets/lang',
      fallbackLocale: const Locale('en'),
      child: const MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        navigatorKey: ContextService.navigatorKey,
        builder: BotToastInit(),
        navigatorObservers: [BotToastNavigatorObserver()],
        localizationsDelegates: context.localizationDelegates,
        supportedLocales: context.supportedLocales,
        locale: context.locale,
        theme: ThemeData(
          pageTransitionsTheme: const PageTransitionsTheme(
            builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            },
          ),
        ),
        home: ChangeNotifierProvider( 
          create: (_) => SplashProvider(),
          child: const SplashScreen(),
        ),
    );
  }
}'''
        .trim() +
    '\n';

final _arTemp = '''
{}'''
        .trim() +
    '\n';
final _enTemp = '''
{}'''
        .trim() +
    '\n';

final _applicationTemp = '''
export 'package:flutter/material.dart';
export 'package:provider/provider.dart';

// export 'common/commons.dart';
export 'screen/screens.dart';
// export 'widget/widgets.dart';
// export 'service/services.dart';
// export 'model/models.dart';

export 'package:chaotic/commons.dart';
export 'package:chaotic/services.dart';
export 'package:chaotic/widgets.dart';
'''
        .trim() +
    '\n';

String _newScreenTemp(String screenNameCamelcase) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:provider/provider.dart';
import '../screens.dart';
import 'package:flutter/material.dart';
'''}

class ${screenNameCamelcase}Screen extends StatefulWidget {
  const ${screenNameCamelcase}Screen({Key? key}) : super(key: key);

  @override
  State<${screenNameCamelcase}Screen> createState() => _${screenNameCamelcase}ScreenState();
}

class _${screenNameCamelcase}ScreenState extends State<${screenNameCamelcase}Screen> {
  late ${screenNameCamelcase}Provider provider;

  @override
  Widget build(BuildContext context) {
    provider = context.watch<${screenNameCamelcase}Provider>();
    return const Scaffold(
      body: Center(child: Text('hello world, this is $screenNameCamelcase screen')),
    );
  }
}'''
          .trim() +
      '\n';
}

String _newProviderTemp(String screenNameCamelcase) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:flutter/material.dart';
'''}

class ${screenNameCamelcase}Provider extends ChangeNotifier{

}'''
          .trim() +
      '\n';
}

String _newWidgetTemp(String widgetName) {
  return '''
  ${Chaotic._applicationFile ?? '''
import 'package:flutter/material.dart';
'''}

class $widgetName extends StatelessWidget {

  const $widgetName ({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.all(8.0),
      child: Text('$widgetName widget'),
    );
  }
}'''
          .trim() +
      '\n';
}

String _modelTemp(String modelName) =>
    '''
// import 'dart:convert';
// https://app.quicktype.io/

extension ${modelName.toCamelcase()}Functions on ${modelName.toCamelcase()}{
}
class ${modelName.toCamelcase()}{
}'''
        .trim() +
    '\n';

String _newServiceTemp(String serviceName) {
  return '''
class ${serviceName}Service {
  ${serviceName}Service._();
  static final _instance = ${serviceName}Service._();
  factory ${serviceName}Service.getInstance() => _instance;
  //--------------------
}'''
          .trim() +
      '\n';
}

Future<void> _exportNewScreen(String screenName) async {
  final exportTemp = '''
export '$screenName/$screenName.dart';
export '$screenName/${screenName}_provider.dart';
'''
          .trim() +
      '\n';
  await _screensFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewCommon(String commonName) async {
  final exportTemp = '''
  export '$commonName.dart';
'''
          .trim() +
      '\n';
  await _commonsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewWidget(String widgetName) async {
  final exportTemp = '''
  export '$widgetName.dart';
'''
          .trim() +
      '\n';
  await _widgetsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewModel(String modelName) async {
  final exportTemp = '''
  export '$modelName.dart';
'''
          .trim() +
      '\n';
  await _modelsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewService(String serviceName) async {
  final exportTemp = '''
  export '$serviceName.dart';
'''
          .trim() +
      '\n';
  await _servicesFile.writeAsString(exportTemp, mode: FileMode.append);
}

String _clearTemp(bool git) =>
    '''
// ignore_for_file: depend_on_referenced_packages, unused_import

import 'package:chaotic_helper/init.dart';
import 'package:chaotic_helper/backend.dart';

Future<void> main() async {
  ${Chaotic.applicationName == null ? '' : 'Chaotic.applicationName = "${Chaotic.applicationName}";'}
  ${git ? 'Chaotic.useGit = true;' : ''}
  
  await Chaotic.clear();
}'''
        .trim() +
    '\n';
